# 2022-07-21 - Balancer Queries

Deployment of the `BalancerQueries` contract. It provides a way to perform queries on swaps, joins and exits, simulating these operations and returning the exact
result they would have if called on the Vault given the current state.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [BSC mainnet addresses](./output/bsc.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Polygon zkeVM mainnet addresses](./output/zkevm.json)
- [Base mainnet addresses](./output/base.json)
- [Fantom mainnet addresses](./output/fantom.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`BalancerQueries` artifact](./artifact/BalancerQueries.json)
